package test.portlet.consumer;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.EventRequest;
import javax.portlet.EventResponse;
import javax.portlet.PortletMode;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import javax.portlet.ResourceRequest;
import javax.portlet.ResourceResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import test.portlet.common.TestEvent;
import test.portlet.consumer.main.ConsumerWindow;

import com.vaadin.Application;
import com.vaadin.terminal.gwt.server.PortletApplicationContext2;
import com.vaadin.ui.Window;
import com.vaadin.ui.Window.Notification;

public class ConsumerApplication extends Application {
    private static final long serialVersionUID = 1L;

    private Log log = LogFactory.getLog(this.getClass());

    private ConsumerWindow consumerWindow;

    private ConsumerController controller;

    public ConsumerController getController() {
        return controller;
    }

    public void init() {
        setTheme("reindeer");
        
        controller = new ConsumerController(this);
        controller.init();

        consumerWindow = new ConsumerWindow();
        consumerWindow.init();
        setMainWindow(consumerWindow);

        if (isInPortletContext()) {
            PortletApplicationContext2 ctx = (PortletApplicationContext2) getContext();
            ctx.addPortletListener((Application) this, new ConsumerListener());
        } else {
            getMainWindow().showNotification("Not inited via Portal!",
                    Notification.TYPE_ERROR_MESSAGE);
            controller.updateContent(0);
        }
        log.trace("init() called");        
    }

    private class ConsumerListener implements PortletApplicationContext2.PortletListener {
        private static final long serialVersionUID = 1L;

        @Override
        public void handleActionRequest(ActionRequest request, ActionResponse response,
                Window window) {
            // TODO check how to handle this request
            log.trace("handleActionRequest() called");
        }

        @Override
        public void handleEventRequest(EventRequest request, EventResponse response, Window window) {
            log.trace("handleEventRequest() called");
            if (request.getEvent().getName().equals("event")) {
                TestEvent event = (TestEvent) request.getEvent().getValue();
                if (event.getReceiver().equals("consumer")) {
                    log.debug("event received: " + event);
                    controller.updateContent(event.getMessage());
                }
            }
        }

        @Override
        public void handleRenderRequest(RenderRequest request, RenderResponse response,
                Window window) {
            log.trace("handleRenderRequest() called");
            // check mode in request and act accordingly
            if (PortletMode.VIEW.equals(request.getPortletMode())) {
                log.trace("PortletMode.VIEW mode requested");
            } else if (PortletMode.EDIT.equals(request.getPortletMode())) {
                // edit mode is active
                log.trace("PortletMode.EDIT mode requested");
            }
        }

        @Override
        public void handleResourceRequest(ResourceRequest request, ResourceResponse response,
                Window window) {
            // TODO Auto-generated method stub
            log.trace("handleResourceRequest() called");
        }
    }

    public boolean isInPortletContext() {
        return getContext() instanceof PortletApplicationContext2;
    }

    public ConsumerWindow getMainWindow() {
        return this.consumerWindow;
    }

}
